@@ -10,7 +10,7 @@ var searchData=
   ['file_20encoding_7',['XKB-542 – Invalid file encoding',['../error-index.html#XKB-542',1,'']]],
   ['file_20names_8',['Using system file names',['../user-configuration.html#user-config-system-file-names',1,'']]],
   ['file_20not_20found_9',['XKB-338 – Included file not found',['../error-index.html#XKB-338',1,'']]],
-  ['fixes_10',['Fixes',['../release-notes.html#fixes',1,'Fixes'],['../release-notes.html#fixes-1',1,'Fixes'],['../release-notes.html#fixes-2',1,'Fixes'],['../release-notes.html#fixes-3',1,'Fixes'],['../release-notes.html#fixes-4',1,'Fixes'],['../release-notes.html#fixes-5',1,'Fixes'],['../release-notes.html#fixes-6',1,'Fixes'],['../release-notes.html#fixes-7',1,'Fixes'],['../release-notes.html#fixes-8',1,'Fixes'],['../release-notes.html#fixes-9',1,'Fixes'],['../release-notes.html#fixes-10',1,'Fixes'],['../release-notes.html#fixes-11',1,'Fixes'],['../release-notes.html#fixes-12',1,'Fixes']]],
+  ['fixes_10',['Fixes',['../release-notes.html#fixes',1,'Fixes'],['../release-notes.html#fixes-1',1,'Fixes'],['../release-notes.html#fixes-2',1,'Fixes'],['../release-notes.html#fixes-3',1,'Fixes'],['../release-notes.html#fixes-4',1,'Fixes'],['../release-notes.html#fixes-5',1,'Fixes'],['../release-notes.html#fixes-6',1,'Fixes'],['../release-notes.html#fixes-7',1,'Fixes'],['../release-notes.html#fixes-8',1,'Fixes'],['../release-notes.html#fixes-9',1,'Fixes'],['../release-notes.html#fixes-10',1,'Fixes'],['../release-notes.html#fixes-11',1,'Fixes'],['../release-notes.html#fixes-12',1,'Fixes'],['../release-notes.html#fixes-13',1,'Fixes'],['../release-notes.html#fixes-14',1,'Fixes']]],
   ['flags_11',['flags',['../keymap-text-format-v1-v2.html#generic-flags',1,'Generic flags'],['../keymap-text-format-v1-v2.html#section-flags-def',1,'Section flags'],['../keymap-text-format-v1-v2.html#symbols-flags',1,'Symbols flags']]],
   ['flags_20actions_12',['Control flags actions',['../keymap-text-format-v1-v2.html#control-flags-actions',1,'']]],
   ['for_20available_20rmlvo_13',['Query for available RMLVO',['../group__registry.html',1,'']]],
